@@ -36,7 +36,7 @@ def create_nginx_file(project_path,prj_name,domain_name):
             os.mkdir("/etc/nginx/sites-available")
         except Exception as e:
             pass
-        with open(f"/etc/nginx/sites-available/{prj_name}.conf","w") as f:
+        with open(f"/etc/nginx/sites-available/{prj_name}","w") as f:
             f.write(f"""\
 server {{
     listen 80;
